@@ -24,12 +24,12 @@ def get_movie(url):
 
     # get movie details
     for li in root.xpath('//div[@class="inattr"]//li'):
-        texts = list(text.lower().strip() for text in li.itertext())
+        texts = list(text.lower().strip().replace(' ', '_') for text in li.itertext())
         key = texts[0].replace(':', '')
         value = ' '.join(texts[1:]).strip()
 
         # get imdb link
-        if key == 'imdb rating':
+        if key == 'imdb_rating':
             datas['imdb'] = li.xpath('./a')[0].attrib['href']
 
     attrs = root.xpath('//div[@class="outattr"]/div[@class="attr"]')
@@ -79,7 +79,7 @@ def get_movies(kind, page, search=None):
             # find movie informations like genre, quality...
             infos = {}
             for li in mv.xpath('.//li'):
-                texts = list(text.lower().strip() for text in li.itertext())
+                texts = list(text.lower().strip().replace(' ', '_') for text in li.itertext())
                 # remove : for first item, and convert string to lowercase
                 texts[0] = texts[0].replace(':', '').lower()
                 # use first item as key, others as value
@@ -116,19 +116,19 @@ def get_url(kind, page, search=None):
 
 
 @asyncio.coroutine
-def latest(page):
+def latest(page=1):
     '''Show latest movies.'''
     return get_movies('latest', page)
 
 
 @asyncio.coroutine
-def popular(page):
+def popular(page=1):
     '''Show popular movies.'''
     return get_movies('popular', page)
 
 
 @asyncio.coroutine
-def search(keyword, page):
+def search(keyword, page=1):
     '''Search movies.'''
     return get_movies('search', page, keyword)
 
